# Copyright (C) 2020-Present the hyssop authors and contributors.
#
# This module is part of hyssop and is released under
# the MIT License: http://www.opensource.org/licenses/mit-license.php

'''
File created: September 4th 2020

Modified By: howardlkung
Last Updated: February 3rd 2021 20:35:32 pm
'''

Localization_File = 'local.csv'

# db util
LocalCode_No_Valid_DT_FORMAT = 500              # args: (str)
LocalCode_Not_Allow_Update = 501                # args: (str)
LocalCode_Must_Be_Type = 502                    # args: (str, Type)
LocalCode_Invalid_Column = 503                  # args: (str)
LocalCode_Invalid_Boolean = 504                 # args: (var)

# db util
LocalCode_Missing_File_Path = 510               # args: ()
LocalCode_Missing_Host = 511                    # args: ()
LocalCode_Missing_User = 512                    # args: ()
LocalCode_Missing_Password = 513                # args: ()
LocalCode_Missing_DB_Name = 514                 # args: ()
LocalCode_Is_Not_Sub_Type = 515                 # args: (), ()
LocalCode_Method_Is_Not_Belong_To_Class = 516   # args: ()
LocalCode_Primary_Key_required = 517            

# uw component
LocalCode_Not_Support_DB_Module = 520           # args: (), ()
